View

Struct View 

pub struct View<S> { /* private fields */ }
A view into the content of a Snapshot that can be used to read or write into it.

There are two types of views:

  • CowView: A copy-on-write view where changes to the view do not affect the root snapshot.
  • MutView: A mutable view where changes to the view modify the root snapshot.

Normal rust borrowing semantics apply, where only one mutable view can exist at a time, and multiple immutable views can exist simultaneously. Both views are tied to the lifetime with which they borrow the snapshot, so they cannot outlive the snapshot they reference.

A third type of view ArcView is similar to CowView but must be created from a reference-counted Arc<Snapshot>. Unlike CowView, it has no lifetime requirements.

Implementations

Source

impl<S> View<S>

pub fn len(&self) -> usize

Returns the length of the view in bytes.

pub fn is_empty(&self) -> bool

Returns true if the view is empty.

pub fn as_slice(&self) -> &[u8]

Returns a slice containing the entire view. This is equicalent to &view[..],

pub fn as_mut_slice(&mut self) -> &mut [u8]

Returns a mutable slice containing the entire view. This is equicalent to &mut view[..],

pub fn as_ptr(&self) -> *const u8

Returns the base pointer of the view.

pub fn as_mut_ptr(&mut self) -> *mut u8

Returns the base mutable pointer of the view.

pub fn take_snapshot(&self) -> Result<Snapshot>

Creates a new snapshot from the current content of this view, including any changes made to it.

Note: This method copies the entire content of the view and depending on the size of the snapshot, it can be slow.

pub fn restore(&mut self) -> Result<()>

Discard any changes made to this copy-on-write view, restoring it to the original content of the root snapshot. Restoring a view also reverts any memory protection applied to the view. Restoring a view does not change its address.