Skip to main contentCrate memsnap
Source - Snapshot
- A representation of a memory snapshot.
To access the content of the snapshot you need to create a
View with one of: - View
- A view into the content of a
Snapshot that can be used to
read or write into it.
- page_size
- Returns the system page size in bytes.
This is the granularity at which memory allocation is done on the system.
- ArcView
- A copy-on-write view into the content of a
Snapshot,
similar to CowView but with 'static lifetime.
See View for more details. - CowView
- A copy-on-write view into the content of a
Snapshot.
Changes to this view do not affect the root snapshot.
See View for more details. - MutView
- A mutable view into the content of a
Snapshot.
Changes to this view are reflected in the root snapshot.
See View for more details.